%define debug_package %{nil}
%define product_family OpenCloudOS
%define variant_titlecase Server
%define variant_lowercase server
%define opencloudos_release_name Final
%ifarch %{arm}
%define release_name AltArch
%define contentdir   altarch
%else
%define release_name Core
%define contentdir   centos
%endif
%ifarch ppc64le
%define tuned_profile :server
%endif
%define infra_var stock
%define base_release_version 8
%define upstream_base_release_version 8
%define full_release_version 8.8
%define upstream_full_release_version 8
%define dist_release_version 8
%define upstream_rel_long 8.8-0
%define upstream_rel 8.8
%define centos_rel 8.2305
#define beta Beta
%define dist .oc%{dist_release_version}

# upstream, for rhel and centos 
%define upstream_product_family OpenCloudOS
%define upstream_base_release_version 8
%define upstream_full_release_version 8.8
%define upstream_release_name Final

# The anaconda scripts in %%{_libexecdir} can create false requirements
%global __requires_exclude_from %{_libexecdir}

Name:           opencloudos-release
Version:        %{full_release_version}
Release:        2%{?dist}
Summary:        %{product_family} release file
Group:          System Environment/Base
License:        Mulan PSL v2
%ifnarch %{arm}
%define pkg_name %{name}
%else
Requires:       extlinux-bootloader
%define pkg_name centos-userland-release
%package -n %{pkg_name}
Summary:        %{product_family} release file
%endif
Obsoletes:      rawhide-release redhat-release-as redhat-release-es redhat-release-ws redhat-release-de comps rpmdb-redhat fedora-release redhat-release centos-release centos-release-cr
Provides:       centos-release = 8.8
Provides:       opencloudos-release = %{full_release_version}
Provides:       centos-release(upstream) = %{upstream_rel}
Provides:       redhat-release = %{upstream_rel_long}
Provides:       system-release = %{full_release_version}
Provides:       system-release(releasever) = %{base_release_version}
Provides:       base-module(platform:el8)
Provides:       base-module(platform:oc8)

Provides:       opencloudos-release-eula
Provides:       centos-release-eula
Provides:       redhat-release-eula

Source1:        85-display-manager.preset
Source2:        90-default.preset
Source3:        99-default-disable.preset

Source11:       RPM-GPG-KEY-OpenCloudOS

Source99:       update-boot
Source100:      rootfs-expand

Source200:      EULA
Source201:      LICENSE

Source300:      OpenCloudOS.repo
Source301:      OpenCloudOS-Sources.repo
Source302:      OpenCloudOS-Debuginfo.repo

%ifarch %{arm}
%description -n %{pkg_name}
%{product_family} release files
%endif

%description
%{product_family} release files
OpenCloudOS team <infrastructure@opencloudos.tech>

%prep
echo OK

%build
echo OK

%install
rm -rf %{buildroot}

# create /etc
mkdir -p %{buildroot}/etc

# create /etc/system-release and /etc/redhat-release
echo "%{upstream_product_family} release %{upstream_base_release_version}.%{centos_rel} (%{release_name}) " > %{buildroot}/etc/centos-release
echo "Derived from Red Hat Enterprise Linux %{upstream_rel} (Source)" > %{buildroot}/etc/centos-release-upstream
ln -s centos-release %{buildroot}/etc/redhat-release
echo "%{product_family} %{full_release_version}" > ${RPM_BUILD_ROOT}/etc/opencloudos-release
ln -s opencloudos-release %{buildroot}/etc/system-release

# create /etc/os-release
install -d -m 0755 %{buildroot}%{_prefix}/lib
cat > %{buildroot}%{_prefix}/lib/os-release << EOF
NAME="%{product_family}"
VERSION="%{full_release_version}"
ID="opencloudos"
ID_LIKE="rhel fedora"
VERSION_ID="%{full_release_version}"
PLATFORM_ID="platform:oc%{upstream_base_release_version}"
PRETTY_NAME="%{product_family} %{full_release_version}"
ANSI_COLOR="0;31"
CPE_NAME="cpe:/o:opencloudos:opencloudos:%{base_release_version}%{?tuned_profile}"
HOME_URL="https://www.opencloudos.org/"
BUG_REPORT_URL="https://bugs.opencloudos.tech/"
EOF

# Create the symlink for /etc/os-release
ln -s ../usr/lib/os-release %{buildroot}%{_sysconfdir}/os-release

# write cpe to /etc/system/release-cpe
echo "cpe:/o:opencloudos:opencloudos:%{base_release_version}" > %{buildroot}/etc/system-release-cpe

# create /etc/issue and /etc/issue.net
echo '\S' > %{buildroot}/etc/issue
echo 'Kernel \r on an \m' >> %{buildroot}/etc/issue
cp %{buildroot}/etc/issue %{buildroot}/etc/issue.net
echo >> %{buildroot}/etc/issue

# copy GPG keys
mkdir -p -m 755 %{buildroot}/etc/pki/rpm-gpg
install -m 644 %{SOURCE11} %{buildroot}/etc/pki/rpm-gpg

# copy yum repos
mkdir -p -m 755 %{buildroot}/etc/yum.repos.d
install -m 644 %{SOURCE300} %{buildroot}/etc/yum.repos.d
install -m 644 %{SOURCE301} %{buildroot}/etc/yum.repos.d
install -m 644 %{SOURCE302} %{buildroot}/etc/yum.repos.d

mkdir -p -m 755 %{buildroot}/etc/dnf/vars
echo "%{infra_var}" > %{buildroot}/etc/dnf/vars/infra
echo "%{contentdir}" >%{buildroot}/etc/dnf/vars/contentdir
echo %{base_release_version} > %{buildroot}/etc/dnf/vars/releasever

# set up the dist tag macros
install -d -m 755 %{buildroot}/etc/rpm
cat >> %{buildroot}/etc/rpm/macros.dist << EOF
# dist macros.

%%centos_ver %{upstream_base_release_version}
%%centos %{upstream_base_release_version}
%%rhel %{upstream_base_release_version}
%%dist .oc%{base_release_version}
%%el%{upstream_base_release_version} 1
%%opencloudos %{base_release_version}
%%opencloudos_ver %{base_release_version}
EOF

# use unbranded datadir
mkdir -p -m 755 %{buildroot}/%{_datadir}/centos-release
ln -s centos-release %{buildroot}/%{_datadir}/redhat-release
ln -s centos-release %{buildroot}/%{_datadir}/opencloudos-release
install -m 644 %{SOURCE200} %{buildroot}/%{_datadir}/centos-release

# use unbranded docdir
mkdir -p -m 755 %{buildroot}/%{_docdir}/centos-release
ln -s centos-release %{buildroot}/%{_docdir}/redhat-release
ln -s centos-release %{buildroot}/%{_docdir}/opencloudos-release
install -m 644 %{SOURCE201} %{buildroot}/%{_docdir}/centos-release

# copy systemd presets
mkdir -p %{buildroot}/%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE1} %{buildroot}/%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE2} %{buildroot}/%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE3} %{buildroot}/%{_prefix}/lib/systemd/system-preset/

%ifarch %{arm}
# Install armhfp specific tools
mkdir -p %{buildroot}/%{_bindir}/
install -m 0755 %{SOURCE99} %{buildroot}%{_bindir}/
install -m 0755 %{SOURCE100} %{buildroot}%{_bindir}/
%endif


%clean
rm -rf %{buildroot}

%files -n %{pkg_name}
%defattr(0644,root,root,0755)
/etc/redhat-release
/etc/system-release
/etc/centos-release
/etc/centos-release-upstream
/etc/opencloudos-release
%config(noreplace) /etc/os-release
%config /etc/system-release-cpe
%config(noreplace) /etc/issue
%config(noreplace) /etc/issue.net
/etc/pki/rpm-gpg/
%config(noreplace) /etc/yum.repos.d/*
%config(noreplace) /etc/dnf/vars/*
/etc/rpm/macros.dist
%{_docdir}/opencloudos-release
%{_docdir}/redhat-release
%{_docdir}/centos-release/*
%{_datadir}/opencloudos-release
%{_datadir}/redhat-release
%{_datadir}/centos-release/*
%{_prefix}/lib/os-release
%{_prefix}/lib/systemd/system-preset/*
%ifarch %{arm}
%attr(0755,root,root) %{_bindir}/update-boot
%attr(0755,root,root) %{_bindir}/rootfs-expand
%endif

%changelog
* Mon Jan 08 2024 Jiaxin Yang <jiaxinyyang@tencent.com> 8.8-2
- Add NFV

* Tue Aug 01 2023 Xin Cheng <denisecheng@tencent.com> 8.8-1
- Version 8.8

* Mon Jan 16 2023 Xin Cheng <denisecheng@tencent.com> 8.6-9
- Update EULA

* Fri Jan 13 2023 Xin Cheng <denisecheng@tencent.com> 8.6-8
- Update EULA and License

* Fri Jan 13 2023 Xun Zhong <invain@opencloudos.tech> 8.6-7
- enable Plus repo by default

* Tue Jan 03 2023 Xun Zhong <invain@opencloudos.tech> 8.6-6
- fix Plus debug repo

* Fri Dec 30 2022 Xun Zhong <invain@opencloudos.tech> 8.6-5
- add Plus repo

* Fri Sep 02 2022 Xun Zhong <invain@opencloudos.tech> 8.6-4
- add debuginfo repo

* Thu Sep 01 2022 maxonxie <maxonxie@opencloudos.tech> 8.6-3
- add os-release symlink

* Fri Aug 26 2022 Xun Zhong <invain@opencloudos.tech> 8.6-2
- add opencloudos-release link

* Mon Jul 25 2022 Xun Zhong <invain@opencloudos.tech> 8.6-1
- version 8.6

* Wed Jul 20 2022 Xun Zhong <invain@opencloudos.tech> 8.5-11
- source repo domain .org -> .tech

* Thu Jul 07 2022 Xun Zhong <invain@opencloudos.tech> 8.5-10
- remove variable not used

* Fri Jun 24 2022 Xun Zhong <invain@opencloudos.tech> 8.5-9
- platform el8 -> oc8

* Wed Jun 22 2022 Xun Zhong <invain@opencloudos.tech> 8.5-8
- trim repos and set org

* Tue Apr 19 2022 Xun Zhong <invain@opencloudos.tech> 8.5-7
- update EULA

* Fri Feb 18 2022 Xun Zhong <invain@opencloudos.tech> 8.5-6
- fix macros.dist

* Tue Jan 25 2022 Xun Zhong <invain@opencloudos.tech> 8.5-5
- fix testing repo url

* Mon Jan 24 2022 Xun Zhong <invain@opencloudos.tech> 8.5-4
- update mirrors.opencloudos.tech

* Mon Jan 24 2022 Xun Zhong <invain@opencloudos.tech> 8.5-3
- repo structure compatible with upstream

* Mon Dec 13 2021 Xun Zhong <invain@opencloudos.tech> 8.5-2
- fix provides centos-release version

* Mon Nov 15 2021 Songqiao Tao <joeytao@opencloudos.tech> 8.5-1
- Create for OpenCloudOS V8.5
